---
title: OAuth Authentication
description: GitHub OAuth social login configuration.
---

import { Callout } from 'nextra/components'

<Callout type="info">
This page has moved. See [OAuth (GitHub)](../../built-in-apps/user-management/accounts/oauth) for the full OAuth documentation.
</Callout>
